{% load cms_tags %}
<section class="text-block">
    <div class="wrapper{% if not instance.left_aligned %} wrapper--mid{% endif %}">
        {% if instance.left_aligned %}<div class="text-block__thin">{% endif %}
            {{ instance.text|safe }}
        {% if instance.left_aligned %}</div>{% endif %}
    </div>
</section>
