# Generated by Django 2.2 on 2021-05-20 07:58

import cms.models.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
        ('cms', '0022_auto_20180620_1551'),
        ('giant_plugins', '0016_featured_cta'),
    ]

    operations = [
        migrations.CreateModel(
            name='LogoBlock',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='giant_plugins_logoblock', serialize=False, to='cms.CMSPlugin')),
                ('title', models.CharField(blank=True, max_length=255)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='LogoCard',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='giant_plugins_logocard', serialize=False, to='cms.CMSPlugin')),
                ('external_url', models.URLField(blank=True, help_text='Overrides the internal link if set')),
                ('name', models.CharField(blank=True, max_length=255)),
                ('internal_link', cms.models.fields.PageField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='cms.Page')),
                ('logo', filer.fields.image.FilerImageField(on_delete=django.db.models.deletion.CASCADE, related_name='company_logo', to=settings.FILER_IMAGE_MODEL)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin', models.Model),
        ),
    ]
