# Generated by Django 2.2 on 2021-08-06 04:42

from django.db import migrations
import django.db.models.deletion
import filer.fields.file


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0012_file_mime_type'),
        ('giant_plugins', '0018_social_share'),
    ]

    operations = [
        migrations.AddField(
            model_name='featuredcta',
            name='file',
            field=filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='featuredcta_files', to='filer.File', verbose_name='File'),
        ),
        migrations.AddField(
            model_name='heroimage',
            name='file',
            field=filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='heroimage_files', to='filer.File', verbose_name='File'),
        ),
        migrations.AddField(
            model_name='logocard',
            name='file',
            field=filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='logocard_files', to='filer.File', verbose_name='File'),
        ),
        migrations.AddField(
            model_name='pagecard',
            name='file',
            field=filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='pagecard_files', to='filer.File', verbose_name='File'),
        ),
    ]
