# Generated by Django 2.2 on 2021-01-05 08:05

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("giant_plugins", "0007_auto_20200930_0750"),
    ]

    operations = [
        migrations.AddField(
            model_name="contentwidthvideo",
            name="alternate_url",
            field=models.URLField(
                blank=True,
                help_text="This will be used if no Youtube URL is provided",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="pagecardblock",
            name="layout",
            field=models.CharField(default="left_right", max_length=255),
        ),
        migrations.AlterField(
            model_name="contentwidthvideo",
            name="youtube_url",
            field=models.URLField(
                blank=True,
                help_text="Enter the full URL of the youtube video page",
                null=True,
                validators=[
                    django.core.validators.URLValidator(
                        message="Please enter the full URL of the Youtube video page",
                        regex="www.youtube.com",
                        schemes=["https"],
                    )
                ],
            ),
        ),
    ]
