{% load cms_tags static %}
<section class="inline-quote">
    <div class="wrapper wrapper--mid">
        <div class="inline-quote__carousel">
            <span class="prev"><img src="{% static 'img/carousel--prev.svg' %}" alt="Previous" /></span>
            <div class="inline-quote__slides">
                {% for plugin in instance.child_plugin_instances %}
                    <div class="inline-quote__slide">
                        {% render_plugin plugin %}
                    </div>
                {% endfor %}
            </div>
            <span class="next"><img src="{% static 'img/carousel--next.svg' %}" alt="Next" /></span>
        </div>
    </div>
</section>
