# Generated by Django 2.2 on 2021-03-08 04:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
        ('giant_plugins', '0013_auto_20210225_0334'),
    ]

    operations = [
        migrations.CreateModel(
            name='Donate',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='giant_plugins_donate', serialize=False, to='cms.CMSPlugin')),
                ('campaign', models.CharField(max_length=255)),
                ('donation_url', models.URLField()),
                ('title', models.CharField(blank=True, max_length=255)),
                ('text', models.TextField(blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
