<section class="cta-banner">
    <div class="wrapper">
        <div class="cta-banner__container">
            <div class="cta-banner__title">
                {{ instance.title|safe }}
            </div>
            <div class="cta-banner__info">
                <p>{{ instance.caption }}</p>
            </div>
            <div class="cta-banner__cta">
                <a href="{{ instance.get_absolute_url }}" title="{{ instance.cta_text }}" class="btn"{% if instance.external_url %} target="_blank" rel="noreferrer noopener"{% endif %}>{{ instance.cta_text }}</a>
            </div>
        </div>
    </div>
</section>