# Generated by Django 2.2 on 2021-05-20 07:26

import cms.models.fields
from django.db import migrations, models
import django.db.models.deletion
import giant_plugins.utils


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
        ('giant_plugins', '0015_replace_null_with_default'),
    ]

    operations = [
        migrations.CreateModel(
            name='FeaturedCTA',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='giant_plugins_featuredcta', serialize=False, to='cms.CMSPlugin')),
                ('external_url', models.URLField(blank=True, help_text='Overrides the internal link if set')),
                ('title', giant_plugins.utils.RichTextField()),
                ('caption', models.CharField(blank=True, max_length=255)),
                ('cta_text', models.CharField(max_length=255)),
                ('internal_link', cms.models.fields.PageField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='cms.Page')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin', models.Model),
        ),
    ]
