# Generated by Django 2.2 on 2021-01-29 09:29

from django.conf import settings
from django.db import migrations
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0010_add_title_to_pagecard'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pagecard',
            name='image',
            field=filer.fields.image.FilerImageField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.FILER_IMAGE_MODEL),
        ),
    ]
