# Generated by Django 2.2 on 2021-02-25 03:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0012_pagecard_cta_text'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagecardblock',
            name='background_colour',
            field=models.CharField(choices=[('dark', 'Dark'), ('light', 'Light')], default='light', max_length=30),
        ),
        migrations.AddField(
            model_name='pagecardblock',
            name='theme',
            field=models.CharField(choices=[('full-width', 'Full width'), ('content-width', 'Content width')], default='content-width', max_length=50),
        ),
    ]
