# Generated by Django 2.2 on 2021-03-08 05:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0014_add_donate_plugin'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contentwidthimage',
            name='alt_text',
            field=models.CharField(blank=True, default='', help_text='Image name', max_length=64),
        ),
        migrations.AlterField(
            model_name='contentwidthvideo',
            name='alt_text',
            field=models.CharField(blank=True, default='', max_length=128),
        ),
        migrations.AlterField(
            model_name='contentwidthvideo',
            name='alt_title',
            field=models.CharField(blank=True, default='', max_length=128),
        ),
    ]
