# Generated by Django 2.2 on 2020-09-30 07:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0006_auto_20200930_0519'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contentwidthvideo',
            name='alt_text',
            field=models.CharField(blank=True, max_length=128, null=True),
        ),
        migrations.AlterField(
            model_name='contentwidthvideo',
            name='alt_title',
            field=models.CharField(blank=True, max_length=128, null=True),
        ),
    ]
