.ext-databasic {
	position: relative;
	display: block;
	min-height: 50px;
	background-color: cyan;
	text-align: center;
	padding: 20px;
	border: 1px solid white;
	border-radius: 10px;
}

.ext-databasic p {
	color: white;
	font-size: 1.2em;
	margin: 0;
}
