{% load cms_tags %}

<section class="logo-block">
    <div class="wrapper">
        {% if instance.title %}
            <div class="centred-text">
                <h3>{{ instance.title }}</h3>
            </div>
        {% endif %}
        <div class="three-col">
            {% for plugin in instance.child_plugin_instances %}
                {% render_plugin plugin %}
            {% endfor %}
        </div>
    </div>
</section>
