# Generated by Django 2.2 on 2020-09-16 08:32

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
        ('giant_plugins', '0004_remove_pullquote_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='pullquote',
            name='image',
            field=filer.fields.image.FilerImageField(blank=True, help_text='Choose an optional image', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.FILER_IMAGE_MODEL),
        ),
        migrations.AlterField(
            model_name='pagecard',
            name='summary',
            field=models.CharField(blank=True, help_text='Limited to 140 characters', max_length=140),
        ),
        migrations.AlterField(
            model_name='pagecard',
            name='title',
            field=models.CharField(max_length=255),
        ),
    ]
